=========
Changelog
=========

Version 0.0.5
=============

- Media class implementation

Version 0.0.4
=============

- Minimal environment version (stable)
- Fix attribute tests

Version 0.0.3
=============

- Add an extendable components metaclass (Django way).
- Change the regular name attribute to context_name, which it makes more sense.
- Remove some unused app scripts.

Version 0.0.2
=============

- Reformat the library with new standard specifications.
- Fix the test environment

Version 0.0.1
===========

- Initial release
